utils

package
v0.0.0-...-3499ab5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 17, 2025 License: MIT Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var DefaultRetryConfig = RetryConfig{
	MaxRetries: 3,
	RetryDelay: time.Second,
}
var MulticallABI = MulticallMetaData.ABI

MulticallABI is the input ABI used to generate the binding from. Deprecated: Use MulticallMetaData.ABI instead.

var MulticallMetaData = &bind.MetaData{
	ABI: "[{\"constant\":false,\"inputs\":[{\"components\":[{\"name\":\"target\",\"type\":\"address\"},{\"name\":\"callData\",\"type\":\"bytes\"}],\"name\":\"calls\",\"type\":\"tuple[]\"}],\"name\":\"aggregate\",\"outputs\":[{\"name\":\"blockNumber\",\"type\":\"uint256\"},{\"name\":\"returnData\",\"type\":\"bytes[]\"}],\"payable\":false,\"stateMutability\":\"nonpayable\",\"type\":\"function\"}]",
}

MulticallMetaData contains all meta data concerning the Multicall contract.

Functions

func Retry

func Retry[T any](operation func() (T, error), config RetryConfig) (T, error)

func ToSSV

func ToSSV(value *big.Int, format string) string

Types

type Multicall

type Multicall struct {
	MulticallCaller // Read-only binding to the contract
}

Multicall is an auto generated Go binding around an Ethereum contract.

func NewMulticall

func NewMulticall(network string, backend bind.ContractBackend) (*Multicall, error)

NewMulticall creates a new instance of Multicall, bound to a specific deployed contract.

type MulticallCaller

type MulticallCaller struct {
	// contains filtered or unexported fields
}

MulticallCaller is an auto generated read-only Go binding around an Ethereum contract.

func (*MulticallCaller) Aggregate

func (mc *MulticallCaller) Aggregate(opts *bind.CallOpts, calls []Struct0) ([]interface{}, error)

Aggregate : Read-only Solidity: function aggregate((address,bytes)[] calls) returns(uint256 blockNumber, bytes[] returnData)

type RetryConfig

type RetryConfig struct {
	MaxRetries int
	RetryDelay time.Duration
}

type Struct0

type Struct0 struct {
	Target   common.Address
	CallData []byte
}

Struct0 is an auto generated low-level Go binding around an user-defined struct.

Jump to