Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var DefaultRetryConfig = RetryConfig{ MaxRetries: 3, RetryDelay: time.Second, }
var MulticallABI = MulticallMetaData.ABI
MulticallABI is the input ABI used to generate the binding from. Deprecated: Use MulticallMetaData.ABI instead.
var MulticallMetaData = &bind.MetaData{
ABI: "[{\"constant\":false,\"inputs\":[{\"components\":[{\"name\":\"target\",\"type\":\"address\"},{\"name\":\"callData\",\"type\":\"bytes\"}],\"name\":\"calls\",\"type\":\"tuple[]\"}],\"name\":\"aggregate\",\"outputs\":[{\"name\":\"blockNumber\",\"type\":\"uint256\"},{\"name\":\"returnData\",\"type\":\"bytes[]\"}],\"payable\":false,\"stateMutability\":\"nonpayable\",\"type\":\"function\"}]",
}
MulticallMetaData contains all meta data concerning the Multicall contract.
Functions ¶
Types ¶
type Multicall ¶
type Multicall struct {
MulticallCaller // Read-only binding to the contract
}
Multicall is an auto generated Go binding around an Ethereum contract.
func NewMulticall ¶
func NewMulticall(network string, backend bind.ContractBackend) (*Multicall, error)
NewMulticall creates a new instance of Multicall, bound to a specific deployed contract.
type MulticallCaller ¶
type MulticallCaller struct {
// contains filtered or unexported fields
}
MulticallCaller is an auto generated read-only Go binding around an Ethereum contract.
type RetryConfig ¶
Click to show internal directories.
Click to hide internal directories.